summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoGuides.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
committerTimothy Pearson <[email protected]>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /lib/kofficeui/KoGuides.h
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'lib/kofficeui/KoGuides.h')
-rw-r--r--lib/kofficeui/KoGuides.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/kofficeui/KoGuides.h b/lib/kofficeui/KoGuides.h
index b98b0472..7a28962f 100644
--- a/lib/kofficeui/KoGuides.h
+++ b/lib/kofficeui/KoGuides.h
@@ -58,8 +58,8 @@ public:
*/
void paintGuides( TQPainter &painter );
- typedef int SnaptqStatus;
- static const SnaptqStatus SNAP_NONE, SNAP_HORIZ, SNAP_VERT, SNAP_BOTH;
+ typedef int SnapStatus;
+ static const SnapStatus SNAP_NONE, SNAP_HORIZ, SNAP_VERT, SNAP_BOTH;
/**
* @brief Handle mousePressEvent
@@ -148,17 +148,17 @@ public:
* @brief Snap rect to guidelines
*
* This looks for a guide which is in reach for the guide as defined in snap.
* This method has the abillity to combine more calls. The snaptqStatus and diff args are both input and
* output. On first call you should set snaptqStatus to 0. The return value would then show in which
* directions it has snapped. If you combine several KoGuides you can let these output arguments
* be input for the next koGuide. That way you'll always catch the nearest guide.
*
* @param rect the rect which should be snapped
* @param snap the distance within the guide should snap - but always snap if already snapped
* @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param).
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
- void snapToGuideLines( KoRect &rect, int snap, SnaptqStatus &snaptqStatus, KoPoint &diff );
+ void snapToGuideLines( KoRect &rect, int snap, SnapStatus &snapStatus, KoPoint &diff );
/**
* @brief Snap rect to guidelines
@@ -167,10 +167,10 @@ public:
*
* @param pos the position which should be snapped
* @param snap the distance wherein the guide should snap - but always snap if already snapped
* @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param)
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
- void snapToGuideLines( KoPoint &pos, int snap, SnaptqStatus &snaptqStatus, KoPoint &diff );
+ void snapToGuideLines( KoPoint &pos, int snap, SnapStatus &snapStatus, KoPoint &diff );
/**
* @brief tqrepaint guides if any changed snapping status
@@ -188,7 +188,7 @@ public:
*
* @param snappedPoint the point after it has been snapped
*/
- void repaintSnapping( const KoPoint &snappedPoint, SnaptqStatus snaptqStatus );
+ void repaintSnapping( const KoPoint &snappedPoint, SnapStatus snapStatus );
/**
* @brief tqrepaint guides so none is snapped
@@ -148,17 +148,17 @@ public:
*
* This looks for a guide which is in reach for the guide as defined in snap.
- * This method has the abillity to combine more calls. The snaptqStatus and diff args are both input and
- * output. On first call you should set snaptqStatus to 0. The return value would then show in which
+ * This method has the abillity to combine more calls. The snapStatus and diff args are both input and
+ * output. On first call you should set snapStatus to 0. The return value would then show in which
* directions it has snapped. If you combine several KoGuides you can let these output arguments
* be input for the next koGuide. That way you'll always catch the nearest guide.
@@ -148,17 +148,17 @@ public:
* @param rect the rect which should be snapped
* @param snap the distance within the guide should snap - but always snap if already snapped
- * @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param).
+ * @param snapStatus if horiz,vert or both directions are snapped (both in and out param).
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
@@ -167,10 +167,10 @@ public:
* @param pos the position which should be snapped
* @param snap the distance wherein the guide should snap - but always snap if already snapped
- * @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param)
+ * @param snapStatus if horiz,vert or both directions are snapped (both in and out param)
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/